/*
 * Copyright (C) 2009 Caolán McNamara <caolanm@redhat.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <libplanner/planner.h>
#include <stdio.h>

int main(int argc, char *argv[])
{
	MrpApplication *app;
	MrpProject *project;
        GError *err = NULL;

	if (argc < 2)
	{
		fprintf(stderr, "Usage: planner2html INPUT\n");
		fprintf(stderr, "planner2html : error: You need to give an inputfile or use - for stdin\n");
		return -1;
        }

        g_type_init();
        app = mrp_application_new();
        project = mrp_project_new(MRP_APPLICATION(app));

        if (!mrp_project_load(project, argv[1], &err))
	{
		if (!err)
			fprintf (stderr, "Unable to read file: %s", argv[1]);
		else
		{
			fprintf (stderr, "%s", err->message);
			g_error_free (err);
		}
		fprintf (stderr, "\n");
		return -1;
	}

        if (!mrp_project_export(project, "-", "Planner HTML", TRUE, &err))
	{
		if (!err)
			fprintf (stderr, "Unable to export %s to html", argv[1]);
		else
		{
			fprintf (stderr, "%s", err->message);
			g_error_free (err);
		}
		return -1;
	}

	mrp_project_close(project);
	g_object_unref(app);

	return 0;
}
